package net.sf.basedb.clients.web.extensions.list;

import java.util.ArrayList;
import java.util.List;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.clients.web.extensions.fileviewer.FileViewerContext;
import net.sf.basedb.clients.web.extensions.fileviewer.FileViewerUtil;
import net.sf.basedb.clients.web.extensions.list.RelatedItemColumn.Specification;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemContext;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.core.plugin.GuiContext;
import net.sf.basedb.util.Values;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Action factory for adding columns to a table that display items that are linked
	with an any-to-any link.
	The factory will scan the "columns" setting from the current context for 
	entries matching the pattern: |linkName|ITEMTYPE|property
	ITEMTYPE and property are optional.

	@author nicklas
	@since 3.17
*/
public class AnyLinkColumnActionFactory
	extends AbstractJspActionFactory<ListColumnAction<BasicItem, Object>>
{
	
	public AnyLinkColumnActionFactory()
	{}

	/**
		We get the "columns" setting from the current ItemContext and check if
		there seems to be an entry for a related item.
	*/
	@Override
	public boolean prepareContext(InvokationContext<? super ListColumnAction<BasicItem, Object>> context) 
	{
		JspContext jspContext = (JspContext)context.getClientContext();
		SessionControl sc = jspContext.getSessionControl();
		GuiContext guiContext = jspContext.getGuiContext();
		Item item = guiContext.getItem();
		String subContext = Values.getString(guiContext.getSubContext(), "");
		
		String allColumns = null;
		if (RelatedItemExtensionColumn.SUBCONTEXT.equals(subContext)) 
		{
			// The current item should be a Specification instance that may specify
			// the column. Otherwise we load the columns from the regular list context
			// which makes it possible to select linked item columns from a parent/child
			// that are currently available
			Specification spec = jspContext.getCurrentItem();
			if (spec != null) allColumns = spec.actionId;
			subContext = "";
		}
		if (allColumns == null)
		{
			ItemContext cc = sc.getCurrentContext(item, subContext, null);
			if (cc == null) return false;
			allColumns = cc.getSetting("columns");
		}
		if (allColumns == null || !allColumns.contains("|")) return false;

		FileViewerUtil fileViewer = FileViewerUtil.getOrCreate(jspContext, FileViewerContext.file());
		return super.prepareContext(context);
	}

	
	@SuppressWarnings({"unchecked", "rawtypes"})
	@Override
	public ListColumnAction<BasicItem, Object>[] getActions(InvokationContext<? super ListColumnAction<BasicItem, Object>> context) 
	{
		JspContext jspContext = (JspContext)context.getClientContext();
		SessionControl sc = jspContext.getSessionControl();
		GuiContext guiContext = jspContext.getGuiContext();
		Item item = guiContext.getItem();
		String subContext = Values.getString(guiContext.getSubContext(), "");
		String allColumns = null;
		if (RelatedItemExtensionColumn.SUBCONTEXT.equals(subContext)) 
		{
			// The current item should be a Specification instance that may specify
			// the column. Otherwise we load the columns from the regular list context
			Specification spec = jspContext.getCurrentItem();
			if (spec != null) allColumns = spec.actionId;
			subContext = "";
		}
		if (allColumns == null)
		{
			ItemContext cc = sc.getCurrentContext(item, subContext, null);
			if (cc == null) return null;
			allColumns = cc.getSetting("columns");
		}
		if (allColumns == null || !allColumns.contains("|")) return null;

		DbControl dc = jspContext.getDbControl();
		FileViewerUtil fileViewer = FileViewerUtil.get(jspContext);
		List<ListColumnAction<BasicItem, Object>> actions = new ArrayList<>(); 
		for (String col : allColumns.split(","))
		{
			if (col.startsWith("|"))
			{
				ListColumnAction<BasicItem, Object> action = AnyLinkColumn.create(dc, actions.size(), item, col, fileViewer);
				if (action != null) actions.add(action);
			}
		}
		
		if (actions.size() == 0) return null;
		
		return actions.toArray(new ListColumnAction[actions.size()]);
	}
	
}
