package net.sf.basedb.clients.web.extensions.list;


import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.StringUtil;
import net.sf.basedb.util.listable.SourceItemTransformer;

/**
	Related item column that get values from multiple hops betweeen child->parent->child.

	@author nicklas
	@since 3.19.4
*/
public class RelatedItemMultiHopColumn 
	extends RelatedItemColumn
{

	private final RelatedItemColumn nextHop;
	RelatedItemMultiHopColumn(DbControl dc, int index, Specification spec, RelatedItemHelper helper, RelatedItemColumn nextHop)
	{
		super(dc, index, spec, helper);
		this.nextHop = nextHop;
		
		setValueType(nextHop.getValueType());
		setFilterable(nextHop.isFilterable());
		if (nextHop.isFilterable())
		{
			setFilterProperty("/"+spec.directionRaw+"/"+spec.targetType.name()+"/"+spec.subtype+"/"+StringUtil.coalesce(nextHop.getFilterProperty(), nextHop.getProperty()));
		}
		setExportable(nextHop.isExportable());
		if (nextHop.isExportable())
		{
			setExportFormatter(nextHop.getExportFormatter());
			setExportProperty(nextHop.getExportProperty());
		}
		setFormatter(nextHop.getFormatter());
		
		setCellClass(nextHop.getCellClass());
		setCellStyle(nextHop.getCellStyle());
		setDisableOverflowCheck(nextHop.getDisableOverflowCheck());
		setEnumeration(nextHop.getEnumeration());
		setTitle(spec.generateTitle(nextHop.getTitle()));
		setSubtitle(nextHop.getSubtitle());
		setTooltip(spec.generateTooltip(StringUtil.coalesce(nextHop.getTooltip(), nextHop.getTitle())));
	}

	@Override
	public Object getValue(RelatedItemHelper helper, Annotatable item, SourceItemTransformer preTransform) 
	{
		return nextHop.getValue(helper, item, getTransformer());
	}
	
	@Override
	public Object getExportValue(RelatedItemHelper helper, Annotatable item, SourceItemTransformer preTransform) 
	{
		return nextHop.getExportValue(helper, item, getTransformer());
	}

}
