/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.section;

import net.sf.basedb.util.extensions.Action;

/**
	Action that inserts a new section in a jsp page. 

	@author Nicklas
	@since 3.2
	@base.modified $Date$
*/
public interface SectionAction
	extends Action
{

	/**
		ID attribute of the main section tag. You need to set
		this value to reference the tab in a javascript.
		@return The ID, or null
	*/
	public String getId();

	/**
		Additional class attribute of the main section tag that is used
		when the section is visible.
		@return Class attribute, or null to not use any additional class
	*/
	public String getShowClazz();

	/**
		Additional class attribute of the main section tag that is used
		when the section is hidden.
		@return Class attribute, or null to not use any additional class
	*/
	public String getHideClazz();
		
	/**
		Extra CSS style attributes that will be added to the
		<code>style</code> attribute of the main section tag.
		@return Style attributes, or null
	*/
	public String getStyle();
	
	/**
		Extra CSS style attributes that will be added to the
		<code>style</code> attribute of the content section tag.
		@return Style attributes, or null
	*/
	public String getContentStyle();

	/**
		Get the title of the section. 
	*/
	public String getTitle();
	
	/**
		Get the (HTML) contents of the section.
	*/
	public String getContent();
	
}
