/**
	$Id: StringFormatter.java 7648 2019-03-13 14:33:25Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.formatter;

import net.sf.basedb.clients.web.util.HTML;
import net.sf.basedb.util.excel.ExcelFormatter;
import net.sf.basedb.util.excel.ExcelValue;
import net.sf.basedb.util.formatter.Formatter;

/**
	Format a string for output on a web page. This means that the string is
	encoded by the {@link HTML#encodeTags(String)} method to prevent pollution
	of the generated HTML.

	@author nicklas
	@version 2.0
	@base.modified $Date: 2019-03-13 15:33:25 +0100 (Wed, 13 Mar 2019) $
*/
public class StringFormatter
	implements Formatter<String>, ExcelFormatter<String, String>
{

	/**
		Create a new string formatter.
	*/
	public StringFormatter()
	{}
	
	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(String value)
	{
		return value == null ? "" : HTML.encodeTags(value);
	}
	@Override
	public String parseString(String value)
	{
		return value;
	}
	// -------------------------------------------

	/**
		No escaping is needed.
		@since 3.15
	*/
	@Override
	public ExcelValue<String> toExcelValue(String value) 
	{
		return ExcelValue.asString(value);
	}

}
