/**
	$Id: ClonableReporterQuery.java 5897 2011-12-02 11:09:46Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

/**
	An interface that indicates that a query may be used together with
	cloned reporter information.

	@author Nicklas
	@since 3.1
	@base.modified $Date: 2011-12-02 12:09:46 +0100 (Fri, 02 Dec 2011) $
*/
public interface ClonableReporterQuery
{
	/**
		Check if the virtual database that this query is using has 
		cloned reporter annotations or not.
	*/
	public boolean hasClonedReporters();
	
	/**
		Checks if this query is using cloned reporter or not by default.
		The default setting is to use cloned reporters if they are available
		in the experiment.
		
		@return TRUE if this query is using cloned reporters, FALSE if not
	*/
	public boolean useClonedReporters();
	
	/**
		Set if cloned reporters should be used by default or not. Trying to
		set this to true is ignored if {@link #hasClonedReporters()} return false.
		
		@param useClonedReporters TRUE to use cloned reporters by default, 
			FALSE to use the master reporters
	*/
	public void setUseClonedReporters(boolean useClonedReporters);
	
	/**
		Get the virtual database that the query is using.
		@return A virtual db or null if the query is not based on a virtual db
	*/
	public VirtualDb getVirtualDb();
}
