/**
	$Id: ExtendedPropertyLinker.java 7714 2019-05-21 11:37:09Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
	Used to create links from extended property values. If a regular
	expression has been specified the value to link must match that
	regular expression. The url should contain the marker <code>{value}</code>
	which will be replaced with the value to link.
	
	@author nicklas
	@version 2.0
	@base.modified $Date: 2019-05-21 13:37:09 +0200 (Tue, 21 May 2019) $
*/
public class ExtendedPropertyLinker
{

	private static final Pattern REPLACE_VALUE = Pattern.compile("\\{value\\}");
	
	private final Pattern regexp;
	private final Matcher url;
	
	ExtendedPropertyLinker(String regexp, String url)
	{
		this.regexp = regexp == null ? null : Pattern.compile(regexp);
		this.url = REPLACE_VALUE.matcher(url);
	}
	
	/**
		Create a link.
		@param value The value to link
		@return The link, or null if this linker doesn't match the value
	*/
	public String getUrl(Object value)
	{
		if (value == null) return null;
		if (regexp != null && !regexp.matcher(value.toString()).matches())
		{
			return null;
		}
		return url.replaceAll(URLEncoder.encode(value.toString(), StandardCharsets.UTF_8));
	}
	
}
