/*
	$Id: QueryRuntimeFilter.java 6881 2015-04-21 07:59:42Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.query.EntityQuery;

/**
	Represents a filter that is applied to a query just before it
	is executed in order to limit the result. Runtime filters are
	used for two purposes:
	
	<ul>
	<li>Limit the returned items based on the logged in users permissions. 
		A query must never return an item which the logged in user doesn't have 
		read permission to. If the query does that a <code>PermissionDeniedException</code>
		is thrown while trying to access that item. 
		
	<li>Limit the returned items based on the options a client application 
		specifies with the {@link EntityQuery#include(Include[])} and 
		{@link EntityQuery#exclude(Include[])} methods. The default is to return 
		only items which are owned by the logged in user and not flagged as removed.
	</ul>

	@author Nicklas
	@version 2.0
	@see <a href="../../../../../html/developer/api/query_api.html">Developer documentation: The Query API</a>
	@base.modified $Date: 2015-04-21 09:59:42 +0200 (Tue, 21 Apr 2015) $
*/
interface QueryRuntimeFilter
{

	/**
		Enable the filters based on the options specified by the query and
		the logged in users permissions. Implementors should use the manager
		to enable the filters, not the <code>HibernateUtil.enableFilter()</code>
		method. The manager keeps track of already enabled filters and
		also takes care of disabling all filters after the query has been
		executed.
		
		@param manager A manager that is used to actually enabled the filter
		@param query The query that is going to be executed, it is not possible
			to modify the query, the actual HQL may already have been generated
		@param dc The <code>DbControl</code> used for database access and
			permission checking
	*/
	public void enableFilters(QueryRuntimeFilterManager manager, EntityQuery query, DbControl dc);

}
