/*
	$Id: ReporterScoreResultIterator.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.
	
	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.query.ResultIterator;
import net.sf.basedb.core.data.ReporterListScoreData;

/**
	This is a temporary solution for returning reporter list scores 
	as an iterator. This class will be replaced by a more generic query functionality in 
	the future.
	
	@author Nicklas
	@version 2.0
	@see ReporterList
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (Fri, 14 Sep 2012) $
*/
public class ReporterScoreResultIterator
	implements ResultIterator<ReporterScore>
{
	/**
		The internal iterator of data layer objects.
	*/
	private final ScrollIterator<ReporterListScoreData> data;

	/**
		The DbControl that was used in the query.
	*/
	private final DbControl dc;

	/**
		The total number of items.
	*/
	private final long totalCount;
	
	/**
		The type of items returned by the query.
	*/
	private final Item itemType;

	ReporterScoreResultIterator(ScrollIterator<ReporterListScoreData> data, DbControl dc, long totalCount)
	{
		assert data != null : "data == null";
		assert dc != null : "dc == null";
		this.data = data;
		this.dc = dc;
		this.itemType = Item.REPORTERSCORE;
		this.totalCount = totalCount;
	}

	/**
		From the QueryResult interface
		---------------------------------
	*/
	@Override
	public long getTotalCount()
	{
		return totalCount;
	}
	// ---------------------------------
	/**
		From the ResultIterator interface
		---------------------------------
	*/
	@Override
	public void close()
	{
		data.close();
	}
	@Override
	public boolean isClosed()
	{
		return data.isClosed();
	}
	// ---------------------------------

	/*
		From the Iterator interface
		--------------------------------
	*/
	@Override
	public boolean hasNext()
	{
		return data.hasNext();
	}
	@Override
	public ReporterScore next()
	{
		ReporterListScoreData dataObject = data.next();
		ReporterScore itemObject = null;
		if (dataObject != null)
		{
			itemObject = new ReporterScore(dataObject);
		}
		return itemObject;
	}
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public void remove()
	{
		throw new UnsupportedOperationException();
	}
	// ---------------------------------
	
	/**
		Get the type of items contained in this list.
		@return An {@link Item} object or null if not known
	*/
	public Item getItemType()
	{
		return itemType;
	}

}
