/*
	$Id: KeyPermission.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data.keyring;

/**
	Class for holding a keyId and a permission value.
	It implements the <code>Comparable</code> interface to
	be able to sort a <code>List</code> by the keyId value.
	<p>
	Note! The <code>compareTo</code> method of this class
	is not consistent with the <code>equals</code> method of
	any of the subclasses. Ie. the <code>compareTo</code>
	method may return 0, while the <code>equals</code>
	method returns FALSE. This is because we need to compare
	subclasses to each other while sorting a <code>List</code>.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (Fri, 14 Sep 2012) $
*/
public abstract class KeyPermission
	implements Comparable<KeyPermission>
{

	int keyId;
	int permission;

	/**
		Create a new <code>KeyPermission</code> object.
	*/
	public KeyPermission()
	{}

	/**
		Get the id of the key.
	*/
	public final int getKeyId()
	{
		return keyId;
	}
	/**
		Set the id of the key.
	*/
	public final void setKeyId(int keyId)
	{
		this.keyId = keyId;
	}
	/**
		Get the permission.
	*/
	public final int getPermission()
	{
		return permission;
	}
	/**
		Set the permission.
	*/
	public final void setPermission(int permission)
	{
		this.permission = permission;
	}

	/**
		Compare the keyId of this object to the keyId of
		another <code>KeyPermission</code> object.
	*/
	@Override
	public final int compareTo(KeyPermission other)
	{
		return this.keyId - other.keyId;
	}
	

}
