/**
	$Id: SignalTarget.java 4516 2008-09-11 20:09:17Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.signal;

/**
	This interface should be implemented by classes that are able 
	to receive {@link Signal}:s. The class may handle the signals
	themselves by also implementing the {@link SignalHandler}
	interface, or delegate this another {@link SignalHandler}
	class, for example {@link ThreadSignalHandler}.

	@author nicklas
	@version 2.6
	@base.modified $Date: 2008-09-11 22:09:17 +0200 (Thu, 11 Sep 2008) $
*/
public interface SignalTarget
{
	/**
		Get the signal handler that is handling signals on behalf of this
		object. Multiple invokations of this method may receive the same or
		different objects. Null may be returned if, for some reason, the
		current object instance doesn't want to receive signals. Returning
		null is the same as not implementing this interface.
		
		@return A SignalHandler object, or null if the current instance doesn't
			support signals
	*/
	public SignalHandler getSignalHandler();

}
