/**
	$Id: UnsupportedSignalException.java 4516 2008-09-11 20:09:17Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.signal;

/**
	This exception is thrown by signal handlers and others that
	doesn't support a given signal.
	
	@author nicklas
	@version 2.6
	@base.modified $Date: 2008-09-11 22:09:17 +0200 (Thu, 11 Sep 2008) $
*/
public class UnsupportedSignalException
	extends SignalException
{
	
	/**
		
	*/
	private static final long serialVersionUID = 5468472782043551962L;
	private Signal signal;
	
	/**
		Create a new UnsupportedSignalException.
		@param signal The signal that is not supported
	*/
	public UnsupportedSignalException(Signal signal)
	{
		this(signal, null);
	}
	
	/**
		Create a new UnsupportedSignalException with a custom message.
		@param signal The signal that is not supported
		@param msg The message, if null a standard message will be generated
	*/
	public UnsupportedSignalException(Signal signal, String msg)
	{
		super(msg == null ? "Unsupported signal: " + signal : msg);
		this.signal = signal;
	}
	
	/**
		Get the signal that is not supported.
		@return A signal object
	*/
	public Signal getSignal()
	{
		return signal;
	}
	
}
