/*
	$Id: MD5.java 7714 2019-05-21 11:37:09Z nicklas $

	Copyright (C) 2005 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import net.sf.basedb.core.BaseException;

import java.security.MessageDigest;
import java.math.BigInteger;
import java.nio.charset.StandardCharsets;

/**
	This class calculates the MD5 hash of a string and
	returns it represented as a hexadecimal string.

	@author Nicklas
	@version 2.0
*/
public class MD5
{
	/**
	 	Calculates the MD5 hash of an UTF-8 encoded string. 
	*/
	public static String getHashString(String in)
	{
		try
		{
			MessageDigest md5 = MessageDigest.getInstance("MD5");
			BigInteger result = new BigInteger(1, md5.digest(in.getBytes(StandardCharsets.UTF_8)));
			return leftPad(result.toString(16), '0', 32);
		}
		catch (Exception ex)
		{
			throw new BaseException(ex);
		}
	}
	
	public static MessageDigest newInstance()
	{
		try
		{
			return MessageDigest.getInstance("MD5");
		}
		catch (Exception ex)
		{
			throw new BaseException(ex);
		}
	}
	
	public static String getHashString(MessageDigest md5)
	{
		BigInteger result = new BigInteger(1, md5.digest());
		return leftPad(result.toString(16), '0', 32);
	}
	
	/**
		If the string is shorter than the specified length, it is left padded 
		with the specified character. If the string is null or longer than the specified
		length it is returned unchanged.

		@param toPad The string to pad
		@param c The character to pad with
		@param length The length of the resulting string
		@return The left-padded string
	 */
	public static String leftPad(String toPad, char c, int length)
	{
		
		if (toPad != null && toPad.length() < length)
		{
			int numToPad = length - toPad.length();
			char[] padding = new char[numToPad];
			for (int i = 0; i < numToPad; ++i)
			{
				padding[i] = c;
			}
			toPad = new String(padding) + toPad;
		}
		return toPad;
	}
	
}
