/**
	$Id $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.encode;

/**
	Encoder implementation that replaces newline, carriage return, 
	tab and backslash with a space. This encoder is suitable for use with
	tab-separated text files. This encoder is non-symmetrical and the 
	{@link #decode(String)} method simply returns the argument unmodified.
	
	@author Nicklas
	@since 2.15
*/
public class ToSpaceEncoderDecoder 
	implements EncoderDecoder 
{

	public ToSpaceEncoderDecoder()
	{}
	
	/*
		From the EncoderDecoder interface
		---------------------------------
	*/
	@Override
	public boolean isSymmetrical() 
	{
		return false;
	}

	@Override
	public String decode(String s) 
	{
		return s;
	}

	@Override
	public String encode(String s) 
	{
		if (s == null) return null;
		boolean neededEncode = false;
		StringBuilder sb = new StringBuilder(s.length());
		for (int i = 0; i < s.length(); ++i)
		{
			char c = s.charAt(i);
			if (c == '\t' || c == '\n' || c == '\r')
			{
				sb.append(" ");
				neededEncode = true;
			}
			else
			{
				sb.append(c);
			}
		}
		return neededEncode ? sb.toString() : s;
	}
	// -------------------------------------------

}
