/**
	$Id$

	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.formatter;

/**
	Formatter implementation that converts an enum constant 
	into it's name() as the formatted value.

	@author Nicklas
	@since 3.8
*/
public class EnumFormatter<T extends Enum<T>>
	implements Formatter<Enum<T>>
{
	private final Class<T> enumClass;
	private String nullValue = "";

	/**
		Create a new formatter. Null values are formatted as an empty string.
		@param enumClass Only required if using the parseString method
	*/
	public EnumFormatter(Class<T> enumClass)
	{
		this.enumClass = enumClass;
	}

	/**
		Create a new formatter.
		@param enumClass Only required if using the parseString method
		@param nullValue The string to return if a null item is 
			passed to {@link #format(Enum)}
	*/
	public EnumFormatter(Class<T> enumClass, String nullValue)
	{
		this.enumClass = enumClass;
		this.nullValue = nullValue;
	}

	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(Enum<T> value)
	{
		return value == null ? nullValue : value.name(); 
	}

	@Override
	public Enum<T> parseString(String value)
	{
		try
		{
			return Enum.valueOf(enumClass, value);
		}
		catch (Exception ex)
		{}
		return null;
	}
	// -------------------------------------------
		
	
	
}
