/**
	$Id: EqualsConverter.java 5401 2010-09-03 11:58:11Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep.convert;

import net.sf.basedb.core.query.Expression;
import net.sf.basedb.core.query.Restriction;
import net.sf.basedb.core.query.Restrictions;
import net.sf.basedb.util.jep.Jep;

import org.nfunk.jep.ASTConstant;
import org.nfunk.jep.Node;

/**
	Convert the '==' operator
	to a Query API {@link Restriction}.

	@author nicklas
	@version 2.4
	@base.modified $Date: 2010-09-03 13:58:11 +0200 (Fri, 03 Sep 2010) $
*/
public class EqualsConverter
	extends AbstractJepConversionFunction<Node>
{
	
	public EqualsConverter()
	{}
	
	/*
		From the JepConversionFunction interface
		-------------------------------------------
	*/
	@Override
	public boolean isOperator()
	{
		return true;
	}
	/**
		@return The string '=='
	*/
	@Override
	public String getName()
	{
		return "==";
	}
	@Override
	public String getDescription()
	{
		return "Check if two expressions are equal";
	}
	/**
		Convert to restriction by calling {@link Restrictions#eq(Expression, Expression)}.
		If the right-hand node is string constant containing '%' 
		{@link Restrictions#like(Expression, Expression)} is used instead (since 2.16).
	*/
	@Override
	public Restriction toRestriction(Node node)
	{
		Node lNode = node.jjtGetChild(0);
		Node rNode = node.jjtGetChild(1);
		Expression left = Jep.nodeToExpression(lNode);
		Expression right = Jep.nodeToExpression(rNode);
		boolean useLike = false;
		if (rNode instanceof ASTConstant)
		{
			ASTConstant constNode = (ASTConstant)rNode;
			Object constValue = constNode.getValue();
			if (constValue instanceof String) 
			{
				useLike = ((String)constValue).contains("%");
			}
		}
		return useLike ? Restrictions.like(left, right) : Restrictions.eq(left, right);
	}
	// -------------------------------------------

}
