/**
	$Id $

	Copyright (C) 2019 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.filter;

import net.sf.basedb.util.filter.Filter;
import net.sf.basedb.util.overview.Node;

/**
	A filter implementation that matches the node type.
	It will evaluate to true for all {@link Node}:s whose
	{@link Node#getNodeType()} method matches the given node
	type.

	@author Nicklas
	@since 3.16
*/
public class NodeTypeFilter
	implements Filter<Node>
{
	
	private final Node.Type nodeType;
	
	/**
		Create a filter that finds nodes of the given node type.
		@param nodeType The node type to look for
	*/
	public NodeTypeFilter(Node.Type nodeType)
	{
		this.nodeType = nodeType;
	}

	/*
		From the Filter interface
		-------------------------
	*/
	@Override
	public boolean evaluate(Node node)
	{
		return node.getNodeType() == nodeType;
	}
	// -----------------------------
}
