/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.node;

import net.sf.basedb.core.BioPlate;
import net.sf.basedb.core.BioPlateEventParticipant;
import net.sf.basedb.core.BioWell;
import net.sf.basedb.util.overview.Node;

/**
	Name generator implementation for {@link BioPlate} items. The 
	implementation use the {@link NameableNameGenerator} but appends 
	the coordinate of the biomaterial if the parent node  is a 
	biomaterial node. Eg. <code>My plate [A2]</code>. If the parent
	node is a bioplate event, it appends the {@link BioPlateEventParticipant#getRole()}
	to the title.
	
	@author Nicklas
	@since 3.2
	@base.modified $Date$
*/
public class BioPlateNameGenerator
	extends NameableNameGenerator<BioPlate>
{

	private BioPlateEventParticipant currentParticipant;
	private BioWell currentWell;
	
	/**
		Create a new name generator.
		@param namePrefix The prefix to use in node names
		@param titlePrefix The prefix to use in node titles
	*/
	public BioPlateNameGenerator(String namePrefix, String titlePrefix)
	{
		super(namePrefix, titlePrefix);
	}
	
	/*
		From the NameableNameGenerator class
		------------------------------------
	*/
	/**
		The base of the title is generated by the superclass. This
		implementation adds a suffix to the title with the coordinate
		of the biomaterial if the parent node is a biomaterial node.
		If the parent node is a bioplate event, the role of the bioplate
		in the event is added.
	*/
	@Override
	public String getNodeTitle(BioPlate item, Node parentNode)
	{
		String title = super.getNodeTitle(item, parentNode);
		try
		{
			if (currentWell != null)
			{
				title += " [" + currentWell.getCoordinate() + "]";
			}
			else if (currentParticipant != null)
			{
				String role = currentParticipant.getRole();
				if (role != null) title += " [" + role + "]";
			}
		}
		catch (RuntimeException ex)
		{}
		return title;
	}
	// ------------------------
	
	/**
		Set the current bioplate event participant object that should be used when
		generating names for bioplates that are part of a bioplate event.
		@since 3.3
	*/
	public void setCurrentEventParticipant(BioPlateEventParticipant participant)
	{
		this.currentParticipant = participant;
	}

	/**
		Set the current biowell object that should be used when
		generating names for bioplates that are reached by navigating via a biomaterial.
		@since 3.3
	*/
	public void setCurrentBioWell(BioWell well)
	{
		this.currentWell = well;
	}

}

