/**
	$Id: UnitConverter.java 4544 2008-09-25 07:01:30Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.units;

/**
	Interface for converting values between two units. A unit converter
	implemenation usually has a notion of a <i>specific unit</i> and
	a <i>reference unit</i>, which are the two units the converter can
	convert values from.
	<p>
	If rounding errors and truncation is ignored the following should
	hold for any implementation:
	<code>value == converter.convertFrom(converter.convertTo(value))</code>

	@author Nicklas
	@version 2.9
	@base.modified $Date: 2008-09-25 09:01:30 +0200 (Thu, 25 Sep 2008) $
*/
public interface UnitConverter
{
	/**
		Convert a value from the specific unit to the reference unit.
		@param specificValue The value to convert
		@return The converted value
	*/
	public double convertToReferenceUnit(double specificValue);
	
	/**
		Convert a value from the reference unit to the specific unit.
		@param referenceValue The reference value
		@return The converted value
	*/
	public double convertToSpecificUnit(double referenceValue);


}
