/**
	$Id: ZipFileUnpacker.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.plugins;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.LinkedHashSet;
import java.util.Set;
import java.util.zip.ZipInputStream;

import net.sf.basedb.core.AbsoluteProgressReporter;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Directory;
import net.sf.basedb.core.File;
import net.sf.basedb.util.zip.AbstractFileUnpacker;
import net.sf.basedb.util.zip.ZipUnpacker;

/**
	A plugin for unpacking zip and jar file on the BASE file system.
	
	@author nicklas
	@version 2.0
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (Fri, 14 Sep 2012) $
*/
public class ZipFileUnpacker
	extends AbstractFileUnpacker
{
	
	private static final Set<String> extensions =  
		new LinkedHashSet<String>(Arrays.asList("zip", "jar"));

	private static final Set<String> mimeTypes =  
		new LinkedHashSet<String>(Arrays.asList("application/zip", "application/java-archive"));
	
	/*
		From the FileUnpacker interface
		-------------------------------------------
	*/
	@Override
	public String getFormatName()
	{
		return "Zip files";
	}
	/**
		Return a set containing the strings [ zip, jar ].
	*/
	@Override
	public Set<String> getExtensions()
	{
		return extensions;
	}
	/**
		Return a set containing the strings [ application/zip, application/java-archive ].
	*/
	@Override
	public Set<String> getMimeTypes()
	{
		return mimeTypes;
	}
	/**
		Use the {@link ZipUnpacker} to unpack the file.
	*/
	@Override
	public int unpack(DbControl dc, Directory dir, InputStream in,
		File sourceFile, boolean overwrite, AbsoluteProgressReporter progress)
		throws IOException
	{
		ZipUnpacker unpacker = new ZipUnpacker(dc);
		ZipInputStream zipStream = new ZipInputStream(in);
		return unpacker.unpackZipFile(dir, zipStream, sourceFile, overwrite, progress);
	}
	// -------------------------------------------

}
