/*
	$Id: TestContext.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import net.sf.basedb.core.*;

import net.sf.basedb.util.Enumeration;


public class TestContext
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing context");
		write_header();
		
		test_load(Item.FILE, "test", 0);
		int id = test_create(Item.FILE, "test", "new context");
		test_load(Item.FILE, "test", id);
		test_list(Item.FILE, "test", -1);
		
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		test_delete(id);
		write("++Testing context "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create(Item item, String subContext, String name)
	{
		int id = 0;
		try
		{
			SessionControl sc = TestUtil.getSessionControl();
			ItemContext current = sc.getCurrentContext(item, subContext);
			current.setRowsPerPage(60);
			current.setPage(2);
			current.setSortProperty("name");
			current.setSortDirection(ItemContext.SortDirection.ASC);
			id = sc.saveCurrentContextAs(item, name, true, false);
			write_item(0, current);
			write("--Create context OK");
		}
		catch (Throwable ex)
		{
			write("--Create context FAILED");
			ex.printStackTrace();
			ok = false;
		}
		return id;
	}

	static void test_load(Item item, String subContext, int id)
	{
		try
		{
			SessionControl sc = TestUtil.getSessionControl();
			ItemContext current = id == 0 ? sc.getCurrentContext(item, subContext) : sc.loadContext(id);
			write_item(0, current);
			write("--Load context OK");
		}
		catch (Throwable ex)
		{
			write("--Load context FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}


	static void test_list(Item item, String subContext, int expectedResults)
	{
		try
		{
			SessionControl sc = TestUtil.getSessionControl();
			Enumeration<Integer, String> names = sc.getContextNames(item, subContext);
			for (int i = 0; i<names.size(); i++)
			{
				ItemContext named = sc.loadContext(names.getKey(i));
				write_item(i, named);
			}
			if (expectedResults >= 0 && expectedResults != names.size())
			{
				throw new BaseException("Expected "+expectedResults+" results, not "+names.size());
			}
			write("--List contexts OK ("+names.size()+")");
		}
		catch (Throwable ex)
		{
			write("--List contexts FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}

	static void test_delete(int id)
	{
		try
		{
			SessionControl sc = TestUtil.getSessionControl();
			sc.deleteContext(id);
			write("--Delete context OK");
		}
		catch (Throwable ex)
		{
			write("--Delete context FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}

	static void write_header()
	{
		if (!TestUtil.getSilent())
		{
			write("   \tName      \tItem\tRows/page\tPage\tSort on\tDirection");
			write("-- \t--------- \t----\t---------\t----\t-------\t---------");
		}
	}
	static void write_item(int i, ItemContext c)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+c.getName()+"\t"+c.getItemType()+"\t"+
			c.getRowsPerPage()+"\t"+c.getPage()+"\t"+c.getSortProperty()+"\t"+c.getSortDirection());
	}
	static void write(String message)
	{
		System.out.println(message);
	}

}

