<%-- $Id: edit_quota.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Quota"
	import="net.sf.basedb.core.QuotaType"
	import="net.sf.basedb.core.Location"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.query.Restrictions"
	import="net.sf.basedb.core.query.Expressions"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
private String getQuotaInput(Quota quota, QuotaType type, Location location)
{
	long bytes = quota == null ? Quota.UNDEFINED : quota.getQuotaValue(type, location);
	String fBytes = "";
	String clazz = "text";
	if (bytes == Quota.UNLIMITED)
	{
		fBytes = "unlimited";
		clazz += " disabled";
	}
	else if (bytes >= 0)
	{
		fBytes = Values.formatBytes(bytes);
	}
	boolean required = type.getId() == SystemItems.getId(QuotaType.TOTAL) && location == Location.PRIMARY;
	if (required) clazz += " required";

	StringBuilder sb = new StringBuilder();
	sb.append("<input type=\"text\" class=\"").append(clazz).append("\"");
	sb.append(" maxlength=\"16\" style=\"width: 16em;\"");
	sb.append(" name=\"").append(location.name()).append(":").append(type.getId()).append("\"");
	sb.append(" value=\"").append(fBytes).append("\"");
	sb.append(">");
	sb.append("<input type=\"checkbox\" class=\"auto-init\" data-auto-init=\"unlimited-quota\" value=\"1\"");
	sb.append(" name=\"unlimited:").append(location.name()).append(":").append(type.getId()).append("\"");
	sb.append(bytes==Quota.UNLIMITED ? " checked" : "");
	sb.append(" title=\"Unlimited quota\">\n");
	return sb.toString();
}
%>
<%
final Item itemType = Item.QUOTA;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Edit "+itemType);
try
{
	String title = null;
	Quota quota = null;

	if (itemId == 0)
	{
		title = "Create quota";
		cc.removeObject("item");
	}
	else
	{
		quota = Quota.getById(dc, itemId);
		quota.checkPermission(Permission.WRITE);
		cc.setObject("item", quota);
		title = "Edit quota -- " + HTML.encodeTags(quota.getName());
	}
	
	final QuotaType total = QuotaType.getById(dc, SystemItems.getId(QuotaType.TOTAL));

	// Query to retrieve quota types
	final ItemQuery<QuotaType> quotaTypeQuery = QuotaType.getQuery();
	quotaTypeQuery.order(Orders.asc(Hql.property("id")));
	quotaTypeQuery.restrict(
		Restrictions.neq(
			Hql.property("id"), 
			Hql.entity(total)
		)
	);
	quotaTypeQuery.setCacheResult(true);

	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), quota);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~quota.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings" /></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="quota">
		<input type="hidden" name="cmd" value="UpdateItem">

		<div id="page-data" class="datacontainer"
			data-total-quota-id="<%=total.getId()%>"
		></div>

		<t:tabcontrol id="settings" 
			subclass="content dialogtabcontrol"
			position="bottom" remember="<%=quota != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Quota" helpid="quota.edit">
			<table class="fullform input100 smaller">
			<tr>
				<th>Name</th>
				<td colspan="2"><input class="text required auto-init" data-auto-init="<%=quota == null ? "focus-select" : "focus" %>" 
				type="text" name="name" 
					value="<%=HTML.encodeTags(quota == null ? Values.getString(cc.getPropertyValue("name"), "New quota") : quota.getName())%>" 
					maxlength="<%=Quota.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th></th>
				<td><b>Primary location</b></td>
				<td></td>
			</tr>
			<tr>
				<th>Total quota</th>
				<td><%=getQuotaInput(quota, total, Location.PRIMARY)%></td>
				<td></td>
			</tr>
			<%
			ItemResultList<QuotaType> quotaTypes = quotaTypeQuery.list(dc);
			for (QuotaType current : quotaTypes)
			{
				%>
				<tr>
					<th class="subprompt"><%=HTML.encodeTags(current.getName())%></th>
					<td><%=getQuotaInput(quota, current, Location.PRIMARY)%></td>
					<td></td>
				</tr>
				<%
			}
			%>
			<tr>
				<th class="subprompt"></th>
				<td colspan="3">
					<div class="messagecontainer help" style="margin: 0.5em 0px 0.5em 0px;">
						The individual quota values doesn't have to sum up to the total value.
						The most restrictive value is always used.
						You can use the following units (case-insensitive):
						<ul>
						<li><b>Gb</b> or <b>G</b> for gigabyte values (<code>1.5 Gb</code>)
						<li><b>Mb</b> or <b>M</b> for megabyte values (<code>10M</code>)
						<li><b>Kb</b> or <b>K</b> for kilobyte values (<code>800k</code>)
						<li><b>bytes</b> or <b>b</b> for byte values (<code>50 bytes</code>)
						</ul>
					</div>
				</td>
			</tr>
			<tr class="dynamic">
				<th>Description</th>
				<td colspan="2">
					<textarea class="text" rows="6" name="description" id="description"
						><%=HTML.encodeTags(quota == null ? cc.getPropertyValue("description") : quota.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>
		
		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
