<%-- $Id: view_platetype.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Group"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.PlateType"
	import="net.sf.basedb.core.Plate"
	import="net.sf.basedb.core.PlateGeometry"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Include"	
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.MultiPermissions"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Collections"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.Set"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="p" uri="/WEB-INF/path.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.PLATETYPE;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":View "+itemType);
try
{
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);

	String title = null;
	PlateType plateType = PlateType.getById(dc, itemId);
	
	final boolean usePermission = plateType.hasPermission(Permission.USE);
	final boolean writePermission = plateType.hasPermission(Permission.WRITE);
	final boolean deletePermission = plateType.hasPermission(Permission.DELETE);
	final boolean sharePermission = plateType.hasPermission(Permission.SET_PERMISSION);
	final boolean setOwnerPermission = plateType.hasPermission(Permission.SET_OWNER);
	final boolean isRemoved = plateType.isRemoved();
	final boolean isUsed = isRemoved && plateType.isUsed();
	final boolean deletePermanentlyPermission = deletePermission && !isUsed;
	final boolean isOwner = plateType.isOwner();
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, plateType);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title%>" id="view-page">
	<base:head scripts="table.js,tabcontrol-2.js,~platetypes.js" styles="toolbar.css,headertabcontrol.css,path.css,table.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<p:path><p:pathelement 
			title="Plate types" href="<%="index.jsp?ID="+ID%>" 
			/><p:pathelement title="<%=HTML.encodeTags(plateType.getName())%>" 
			/></p:path>
		<div id="page-data" data-item-id="<%=itemId%>"></div>
		
		<t:tabcontrol 
			id="main" 
			subclass="content mastertabcontrol" 
			active="properties">
		<t:tab id="properties" title="Properties">
			<div>
			<table class="fullform bottomborder">
			<tr>
				<th class="itemstatus">
					<base:icon 
						image="shared.png" 
						visible="<%=plateType.isShared()%>"
						tooltip="This item is shared to other users, groups and/or projects"
					/>
					<base:icon 
						id="btnDeletePermanently"
						image="deleted.png"
						tooltip="This item has been flagged for deletion. Click to delete it now."
						enabled="<%=deletePermanentlyPermission %>"
						visible="<%=isRemoved%>" 
					/>
					<base:icon 
						id="btnUsingItems"
						image="used.png" 
						tooltip="This item is used by other items and can't be permanently deleted. Show the items that are using this one"
						visible="<%=isRemoved && isUsed%>" />
				</th>
				<td style="padding: 0px;">
					<tbl:toolbar subclass="bottomborder bg-filled-50">
						<tbl:button 
							id="btnEdit"
							disabled="<%=!writePermission%>" 
							image="edit.png" 
							title="Edit&hellip;" 
							tooltip="<%=writePermission ? "Edit this plate type" : "You do not have permission to edit this plate type"%>" 
						/>
						<tbl:button 
							id="btnDelete"
							disabled="<%=!deletePermission%>" 
							image="delete.png" 
							title="Delete"
							visible="<%=!plateType.isRemoved()%>"
							tooltip="<%=deletePermission ? "Delete this plate type" : "You do not have permission to delete this plate type"%>" 
						/>
						<tbl:button 
							id="btnRestore"
							disabled="<%=!writePermission%>" 
							image="restore.png" 
							title="Restore"
							visible="<%=plateType.isRemoved()%>"
							tooltip="<%=writePermission ? "Restore this plate type" : "You do not have permission to restore this plate type"%>" 
						/>
						<tbl:button 
							id="btnShare"
							disabled="<%=!sharePermission%>"
							image="share.png"
							title="Share&hellip;" 
							tooltip="<%=sharePermission ? "Share this plate type to other user, groups and projects" : "You do not have permission to share this plate type"%>"
						/>
						<tbl:button 
							id="btnSetOwner"
							disabled="<%=!setOwnerPermission%>"
							image="take_ownership.png"
							title="Set owner&hellip;"
							tooltip="<%=setOwnerPermission ? "Change owner of this item" : "You do not have permission to change ownership of this item"%>"
						/>
						<tbl:button 
							id="btnImport"
							image="import.png" 
							data-plugin-type="IMPORT"  
							title="Import&hellip;" 
							tooltip="Import data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
						/>
						<tbl:button 
							id="btnExport"
							image="export.png"
							data-plugin-type="EXPORT" 
							title="Export&hellip;" 
							tooltip="Export data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
						/>
						<tbl:button 
							id="btnRunPlugin"
							image="runplugin.png"  
							data-plugin-type="OTHER" 
							title="Run plugin&hellip;" 
							tooltip="Run a plugin" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
						/>
						<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
							wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
						<tbl:button
							image="help.png"
							subclass="auto-init"
							data-auto-init="help"
							data-help-id="platetype.view.properties"
							title="Help&hellip;"
							tooltip="Get help about this page"
						/>
					</tbl:toolbar>
				</td>
			</tr>
			<tr>
				<th>Name</th>
				<td><%=HTML.encodeTags(plateType.getName())%></td>
			</tr>
			<tr>
				<th>Registered</th>
				<td><%=dateFormatter.format(plateType.getEntryDate())%></td>
			</tr>
			<tr>
				<th>Geometry</th>
				<td><base:propertyvalue item="<%=plateType%>" property="plateGeometry" /></td>
			</tr>
			<tr>
				<th>Owner</th>
				<td><base:propertyvalue item="<%=plateType%>" property="owner" /></td>
			</tr>
			<tr>
				<th>Permissions</th>
				<td><%=PermissionUtil.getFullPermissionNames(plateType)%></td>
			</tr>
			<tr>
				<th>Description</th>
				<td><%=HTML.niceFormat(plateType.getDescription())%></td>
			</tr>
			</table>
			</div>

			<%
			ItemQuery<Plate> plateQuery = plateType.getPlates();
			plateQuery.include(Include.ALL);
			plateQuery.order(Orders.asc(Hql.property("name")));
			ItemResultList<Plate> plates = plateQuery.list(dc);
			%>
			<base:section
				id="plates"
				title="<%="Plates (" + plates.size() + ")"%>"
				context="<%=cc%>"
				>
				<%
				if (plates.size() == 0)
				{
					%>
					<div class="messagecontainer note">
					No plate of this type exists
					(or, you don't have permission to view them).
					</div>
					<%
				}
				else
				{
					%>
					<tbl:table
						id="plateTypes"
						columns="all"
						>
					<tbl:columndef 
						id="name"
						title="Name"
					/>
					<tbl:columndef 
						id="barcode"
						title="Barcode"
					/>
					<tbl:columndef 
						id="destroyed"
						title="Destroyed"
					/>
					<tbl:columndef 
						id="description"
						title="Description"
					/>
					<tbl:data>
						<tbl:headers>
							<tbl:headerrow>
								<tbl:columnheaders />
							</tbl:headerrow>
						</tbl:headers>
						<tbl:rows>
						<%
						for (Plate item : plates)
						{
							%>
							<tbl:row>
								<tbl:cell column="name"><base:icon 
										image="deleted.png" 
										tooltip="This item has been scheduled for deletion" 
										visible="<%=item.isRemoved()%>"
									/><%=Base.getLinkedName(ID, item, false, true)%></tbl:cell>
								<tbl:cell column="barcode"><%=HTML.encodeTags(item.getBarcode())%></tbl:cell>
								<tbl:cell column="destroyed"><%=item.isDestroyed() ? "yes" : "no" %></tbl:cell>
								<tbl:cell column="description"><%=HTML.encodeTags(item.getDescription())%></tbl:cell>
							</tbl:row>
							<%
						}
						%>
						</tbl:rows>
					</tbl:data>
					</tbl:table>
					<%
				}
				%>
			</base:section>
			<jsp:include page="../../common/anytoany/list_anytoany.jsp">
				<jsp:param name="ID" value="<%=ID%>" />
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="title" value="Other items related to this plate type" />
			</jsp:include>
			<jsp:include page="../../common/share/list_share.jsp">
				<jsp:param name="ID" value="<%=ID%>" />
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="title" value="Shared to" />
			</jsp:include>
		</t:tab>
		<t:tab id="events" title="Event types" />
		</t:tabcontrol>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}

%>
